Coverage for scripts/make_docs.py: 0%

1"""Generate the docs."""

2

3 from pathlib import Path

4 import pdoc

5 import pdoc.render

6

7

8 here = Path(__file__).parent

9

10 pdoc.render.configure(

11 docformat="google",

12 footer_text="atlus",

13 favicon="https://whubsch.github.io/atlus_py/atlus_fav.svg",

14 logo="https://whubsch.github.io/atlus_py/logo_black.png",

15)

16 pdoc.pdoc("src/atlus", output_directory=here.parent / "docs")